@@ -1,4 +1,5 @@
 from typing import Union
+
 from mindflow.utils.enum import ExtendedEnum
 
 
@@ -18,14 +19,8 @@ class ModelTypeOpenAI(ExtendedEnum):
     TEXT_EMBEDDING = ModelType.TEXT_EMBEDDING.value
 
 
-ModelTypeUnion = Union[
-    ModelType,
-    ModelTypeName,
-    ModelTypeOpenAI,
-]
-
-
-def get_model_type_static(
-    static: ModelTypeUnion, key: ModelTypeUnion
-) -> ModelTypeUnion:
-    return static.__members__[key.name]
+# ModelTypeUnion = Union[
+#     ModelType,
+#     ModelTypeName,
+#     ModelTypeOpenAI,
+# ]
