@@ -1,11 +1,17 @@
-from typing import Type, Union
-from mindflow.db.objects.service import Service, ServiceConfig
-from mindflow.db.objects.model import Model, ModelConfig
-from mindflow.db.objects.mindflow_model import MindFlowModel, MindFlowModelConfig
+from typing import Type
+from typing import Union
+
 from mindflow.db.objects.document import Document
+from mindflow.db.objects.mindflow_model import MindFlowModel
+from mindflow.db.objects.mindflow_model import MindFlowModelConfig
+from mindflow.db.objects.model import Model
+from mindflow.db.objects.model import ModelConfig
+from mindflow.db.objects.service import Service
+from mindflow.db.objects.service import ServiceConfig
 from mindflow.utils.enum import ExtendedEnum
 
-class ObjectID(ExtendedEnum): 
+
+class ObjectID(ExtendedEnum):
     SERVICE = "service"
     SERVICE_CONFIG = "service_config"
     MODEL = "model"
@@ -13,6 +19,7 @@ class ObjectID(ExtendedEnum):
     MINDFLOW_MODEL_CONFIG = "mindflow_model_config"
     DOCUMENT = "document"
 
+
 class ObjectName(ExtendedEnum):
     SERVICE = "Service"
     SERVICE_CONFIG = "Service Configurations"
@@ -21,6 +28,7 @@ class ObjectName(ExtendedEnum):
     MINDFLOW_MODEL_CONFIG = "Mindflow Model Configurations"
     DOCUMENT = "Document"
 
+
 class ObjectType(ExtendedEnum):
     SERVICE = Service
     SERVICE_CONFIG = ServiceConfig
@@ -30,7 +38,5 @@ class ObjectType(ExtendedEnum):
     MINDFLOW_MODEL_CONFIG = MindFlowModelConfig
     DOCUMENT = Document
 
-OBJECT_UNION = Union[Service, ServiceConfig, Model, ModelConfig, MindFlowModelConfig, Document]
 
-def get_object_static(static: Type[OBJECT_UNION], key: OBJECT_UNION) -> OBJECT_UNION:
-    return static.__members__[key.name]
\ No newline at end of file
+# OBJECT_UNION = Union[Service, ServiceConfig, Model, ModelConfig, MindFlowModelConfig, Document]
