@@ -1,16 +1,16 @@
 """
 Module for recursively extracting all files from a file path.
 """
-
 import logging
 import os
+from typing import List
+from typing import Union
 
-from typing import List, Union
-
-from mindflow.utils.files.git import is_within_git_repo, get_git_files
+from mindflow.utils.files.git import get_git_files
+from mindflow.utils.files.git import is_within_git_repo
 
 
-def extract_files(path: Union[str, os.PathLike]) -> List[str]:
+def extract_files(path) -> List[str]:
     """
     Extract all files from a directory.
     """
